@@ -15,21 +15,12 @@
 ##  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 ##
 
-rrcov.control <- function (alpha=1/2, 
-                            nsamp=500, 
-                            seed=NULL, 
-                            trace=FALSE,
-                            use.correction=TRUE,
-                            adjust=FALSE,
-                            r = 0.45, 
-                            arp = 0.05, 
-                            eps=1e-3, 
-                            maxiter=120
-                           )
+rrcov.control <- function (alpha=1/2, nsamp=500, seed=NULL, tolSolve=10e-14,
+                            trace=FALSE, use.correction=TRUE, adjust=FALSE, 
+                            r = 0.45, arp = 0.05, eps=1e-3, maxiter=120)
 {
-    list(alpha=alpha, nsamp=nsamp, seed=seed, trace=trace, 
-        use.correction=use.correction, adjust=adjust,
-        r = r, arp = arp, eps=eps, maxiter=maxiter
-        )        
-
+    list(alpha=alpha, nsamp=nsamp, seed=seed, 
+        tolSolve=tolSolve, 
+        trace=trace, use.correction=use.correction, adjust=adjust,
+        r = r, arp = arp, eps=eps, maxiter=maxiter)        
 }
